Payload class

Implementers

Constructors

Payload()
Payload.fromJson(Map<String, dynamic> json)

Properties

accountExpireAt ↔ String?
getter/setter pair
androidApplicationId ↔ String?
getter/setter pair
applicationId ↔ String?
getter/setter pair
bootKey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosApplicationId ↔ String?
getter/setter pair
method ↔ String?
getter/setter pair
methods ↔ List<String>?
getter/setter pair
name ↔ String?
getter/setter pair
orderId ↔ String?
getter/setter pair
params ↔ Map<String, dynamic>?
getter/setter pair
pg ↔ String?
getter/setter pair
price ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAgreeWindow ↔ bool?
getter/setter pair
smsUse ↔ int?
getter/setter pair
taxFree ↔ double?
getter/setter pair
useOrderId ↔ bool?
getter/setter pair
userToken ↔ String?
getter/setter pair
ux ↔ String?
getter/setter pair

Methods

getApplicationId() → dynamic
getMethods() → String
getParamsString() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reVal(dynamic value) → String
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited